@@ -4,6 +4,7 @@ from .commands.deploy import deploy
 from .commands.env import env_app
 from .commands.login import login
 from .commands.logout import logout
+from .commands.logs import logs
 from .commands.unlink import unlink
 from .commands.whoami import whoami
 from .logging import setup_logging
@@ -25,6 +26,7 @@ cloud_app = typer.Typer(
 # fastapi cloud [command]
 cloud_app.command()(deploy)
 cloud_app.command()(login)
+cloud_app.command()(logs)
 cloud_app.command()(logout)
 cloud_app.command()(whoami)
 cloud_app.command()(unlink)
